==> dde-shell_1.99.6.tar.xz: BUILD/panels/dock/dcc-dock-plugin/translations/dock_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>PluginArea</name>
    <message>
        <source>Plugin Area</source>
        <translation>插件区域</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>选择显示在任务栏插件区域的图标</translation>
    </message>
</context>
<context>
    <name>dock</name>
    <message>
        <source>Desktop and taskbar</source>
        <translation>桌面和任务栏</translation>
    </message>
    <message>
        <source>Set the display and size of icons on the desktop</source>
        <translation>设置桌面上图标的显示以及图标大小等</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Dock</source>
        <translation>任务栏</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <source>Fashion</source>
        <translation>时尚</translation>
    </message>
    <message>
        <source>Efficient-left</source>
        <translation>高效-居左</translation>
    </message>
    <message>
        <source>Efficient-center</source>
        <translation>高效-居中</translation>
    </message>
    <message>
        <source>Dock size</source>
        <translation>任务栏大小</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>小</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>大</translation>
    </message>
    <message>
        <source>Position on the screen</source>
        <translation>屏幕中的位置</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>状态</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>一直显示</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>一直隐藏</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>智能隐藏</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>多屏显示</translation>
    </message>
    <message>
        <source>Set the position of the taskbar on the screen</source>
        <translation>设置任务栏在屏幕中的位置</translation>
    </message>
    <message>
        <source>Only on main</source>
        <translation>仅主屏显示</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>跟随鼠标位置显示</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>插件区域</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>选择显示在任务栏插件区域的图标</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.7.tar.xz: BUILD/panels/dock/dcc-dock-plugin/translations/dock_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>PluginArea</name>
    <message>
        <source>Plugin Area</source>
        <translation>插件区域</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>选择显示在任务栏插件区域的图标</translation>
    </message>
</context>
<context>
    <name>dock</name>
    <message>
        <source>Desktop and taskbar</source>
        <translation>桌面和任务栏</translation>
    </message>
    <message>
        <source>Set the display and size of icons on the desktop</source>
        <translation>设置桌面上图标的显示以及图标大小等</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Dock</source>
        <translation>任务栏</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>经典模式</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>居中模式</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>时尚模式</translation>
    </message>
    <message>
        <source>Dock size</source>
        <translation>任务栏大小</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>小</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>大</translation>
    </message>
    <message>
        <source>Position on the screen</source>
        <translation>屏幕中的位置</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>状态</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>一直显示</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>一直隐藏</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>智能隐藏</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>多屏显示</translation>
    </message>
    <message>
        <source>Set the position of the taskbar on the screen</source>
        <translation>设置任务栏在屏幕中的位置</translation>
    </message>
    <message>
        <source>Only on main</source>
        <translation>仅主屏显示</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>跟随鼠标位置显示</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>插件区域</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>选择显示在任务栏插件区域的图标</translation>
    </message>
</context>
</TS>
